@@ -3,9 +3,8 @@ package Win32::WindowsUpdate;
 use strict;
 use warnings;
 use Win32::OLE qw(in);
-use Inline::WSC;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -40,6 +39,12 @@ greatly appreciated.
   $wu->install(@updates); # install your selected updates
   print "Installed updates want you to reboot...\n" if $wu->rebootRequired;
 
+  # .. or to blindly install all updates:
+
+  use Win32::WindowsUpdate;
+  my $wu = Win32::WindowsUpdate->new;
+  $wu->install($wu->updates);
+
 =head1 METHODS
 
 =head2 new
@@ -172,116 +177,71 @@ sub installed
     # .. or .. (both ways will work)
     push(@updates, $update);
   }
-
   $wu->install(@updates);
 
+  # .. or ..
+
+  $wu->install($wu->updates); # if you want to install all updates
+
 Install specified updates.
 Provide an array of either C<update> (directly from C<< $wu->updates >>) or C<updateId>.
 See example above for usage.
 
-Currently implemented via VBScript (via L<Inline::WSC>).
-Perl code exists in the module to do it without VBScript, but it doesn't work.
-If you would like to help, please check out the source of this module to see what's going on there.
-
 =cut
 
 sub install
 {
   my $self = shift;
+  my @updates = @_;
 
-  return undef unless scalar(@_); # no updates specified?  don't run.
+  return undef unless scalar(@updates); # no updates specified?  don't run.
 
-  # using vbscript makes me sad... (see commented broken perl code after this sub)
-  my $VBSCRIPT = <<VBSCRIPT;
-    Sub vbInstall()
-      Set vbSession = CreateObject("Microsoft.Update.Session")
-      Set vbSearcher = vbSession.CreateUpdateSearcher()
-      Set vbSysInfo = CreateObject("Microsoft.Update.SystemInfo")
-      Set vbUpdateColl = CreateObject("Microsoft.Update.UpdateColl")
-      Set vbSearchResult = vbSearcher.Search("IsInstalled = 0 AND IsHidden = 0")
-
-      For i = 0 To vbSearchResult.Updates.Count - 1
-        Set vbUpdate = vbSearchResult.Updates.Item(i)
-VBSCRIPT
-
-  # I'm sure there's a better way...
-  foreach (@_)
+  my %updates;
+  # I'm sure there's a better way... gimme patch!
+  foreach my $update (@updates)
   {
-    my $uid = (ref($_) eq 'HASH' ? uc($_->{UpdateId}) : uc($_));
-    warn("To install: $uid\n");
-    $VBSCRIPT .= <<VBMATCHCODE;
-        If UCase(vbUpdate.Identity.UpdateID) = "$uid" Then
-          vbUpdate.AcceptEula
-          vbUpdateColl.Add(vbUpdate)
-        End If
-VBMATCHCODE
+    my $uid = (ref($update) eq 'HASH' ? $update->{UpdateId} : $update);
+    $updates{$uid}++;
   }
 
-  $VBSCRIPT .= <<VBSCRIPT;
-      Next
+  my $updatecoll = Win32::OLE->new('Microsoft.Update.UpdateColl') or die "ERROR creating Microsoft.Update.UpdateColl\n";
+  $updatecoll->Clear;
 
-      Set vbDownloader = vbSession.CreateUpdateDownloader()
-      vbDownloader.Updates = vbUpdateColl
-      Set vbDownloadResult = vbDownloader.Download()
+  my $queryResult = $self->{updateSearcher}->Search("IsInstalled = 0 AND IsHidden = 0") or die "ERROR in query\n";
+  my $updates = $queryResult->Updates;
 
-      Set vbInstaller = vbSession.CreateUpdateInstaller()
-      vbInstaller.Updates = vbUpdateColl
-      Set vbInstallationResult = vbInstaller.Install()
-    End Sub
-VBSCRIPT
+  foreach my $update (in $updates)
+  {
+    my $updateID = $update->Identity->UpdateID;
+    next unless $updates{$updateID};
+    $update->AcceptEula;
+    $updatecoll->Add($update);
+  }
 
-  Inline::WSC->compile(VBScript => $VBSCRIPT);
-  vbInstall();
+  my $downloader = $self->{updateSession}->CreateUpdateDownloader;
+  $downloader->LetProperty('Updates', $updatecoll);
+  my $downloadResult = $downloader->Download;
+
+  my $installer = $self->{updateSession}->CreateUpdateInstaller;
+  $installer->LetProperty('Updates', $updatecoll);
+  $installer->{AllowSourcePrompts} = 0;
+  $installer->{ForceQuiet} = 1;
+  my $installResult = $installer->Install;
+
+  return $installResult->ResultCode;
 }
 
-# the perl way, but it doesn't seem to work... let me know how to fix it if you figure it out.
-# if you fix it, include code that does accomplishes this: my $uid = (ref($_) eq 'HASH' ? uc($_->{UpdateId}) : uc($_));
-#sub install
-#{
-#  my $self = shift;
-#  my @updates = @_;
-#
-#  return undef unless scalar(@updates); # no updates specified?  don't run.
-#
-#  my $updatecoll = Win32::OLE->new('Microsoft.Update.UpdateColl') or die "ERROR creating Microsoft.Update.UpdateColl\n";
-#  $updatecoll->Clear;
-#
-#  my $queryResult = $self->{updateSearcher}->Search("IsInstalled = 0 AND IsHidden = 0") or die "ERROR in query\n";
-#  my $updates = $queryResult->Updates;
-#
-#  foreach my $update (in $updates)
-#  {
-#    my $updateID = $update->Identity->UpdateID;
-#    next unless grep(m/^$updateID$/i, @updates);
-#    $update->AcceptEula;
-#    $updatecoll->Add($update);
-#    printf("Adding %s %s to collection\n", $updateID, $update->Title);
-#  }
-#
-#  printf("Updates to install: %d\n", $updatecoll->Count);
-#
-#  my $downloader = $self->{updateSession}->CreateUpdateDownloader;
-#  $downloader->{Updates} = $updatecoll;
-#  my $downloadResult = $downloader->Download;
-#
-#  my $installer = $self->{updateSession}->CreateUpdateInstaller;
-#  $installer->{Updates} = $updatecoll; # <<<<<<<<<<<< problem is here... FIXME!
-#  $installer->{AllowSourcePrompts} = 0;
-#  $installer->{ForceQuiet} = 1;
-#  my $installResult = $installer->Install;
-#
-#  use Data::Dumper;
-#  print Dumper($updatecoll, $downloader, $downloadResult, $installer, $installResult);
-#}
-
 =head2 rebootRequired
 
   my $needToReboot = $wu->rebootRequired();
 
 Returns bool.  True if reboot is required, false otherwise.
 
+This doesn't necessarily mean any installs will fail, but there is something pending a reboot.
+Your install might fail, though.  Keep this in mind.
+
 You should check this before and after you run C<install>.
-If it's true before you install, you'll want to reboot before you install.
+If it's true before you install, you may want to reboot before you install.
 If it's true after you install, you'll want to reboot sometime.
 
 =cut
@@ -318,6 +278,18 @@ sub installerBusy
 
 =item Provide ability to install specific updates.
 
+=item Provide ability to hide and unhide specific updates.
+
+=item Provide ability to uninstall updates (maybe?).
+
+=item Provide ability to do background install with ability to check on status.
+
+=item Provide ability to only download updates, not install them.
+
+=item Provide ability to change "Automatic Updates" settings.
+
+=item Provide ability to disable/enable "Please reboot..." nag messages after update install.
+
 =item Determine other necessary features. (email me with your requests)
 
 =back
